==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/regions/bn.php <==
<?php

return [
    'Names' => [
        'AD' => 'আন্ডোরা',
        'AE' => 'সংযুক্ত আরব আমিরাত',
        'AF' => 'আফগানিস্তান',
        'AG' => 'অ্যান্টিগুয়া ও বারবুডা',
        'AI' => 'এ্যাঙ্গুইলা',
        'AL' => 'আলবেনিয়া',
        'AM' => 'আর্মেনিয়া',
        'AO' => 'অ্যাঙ্গোলা',
        'AQ' => 'অ্যান্টার্কটিকা',
        'AR' => 'আর্জেন্টিনা',
        'AS' => 'আমেরিকান সামোয়া',
        'AT' => 'অস্ট্রিয়া',
        'AU' => 'অস্ট্রেলিয়া',
        'AW' => 'আরুবা',
        'AX' => 'আলান্ড দ্বীপপুঞ্জ',
        'AZ' => 'আজারবাইজান',
        'BA' => 'বসনিয়া ও হার্জেগোভিনা',
        'BB' => 'বারবাদোস',
        'BD' => 'বাংলাদেশ',
        'BE' => 'বেলজিয়াম',
        'BF' => 'বুরকিনা ফাসো',
        'BG' => 'বুলগেরিয়া',
        'BH' => 'বাহরাইন',
        'BI' => 'বুরুন্ডি',
        'BJ' => 'বেনিন',
        'BL' => 'সেন্ট বারথেলিমি',
        'BM' => 'বারমুডা',
        'BN' => 'ব্রুনেই',
        'BO' => 'বলিভিয়া',
        'BQ' => 'ক্যারিবিয়ান নেদারল্যান্ডস',
        'BR' => 'ব্রাজিল',
        'BS' => 'বাহামা দ্বীপপুঞ্জ',
        'BT' => 'ভুটান',
        'BV' => 'বোভেট দ্বীপ',
        'BW' => 'বতসোয়ানা',
        'BY' => 'বেলারুশ',
        'BZ' => 'বেলিজ',
        'CA' => 'কানাডা',
        'CC' => 'কোকোস (কিলিং) দ্বীপপুঞ্জ',
        'CD' => 'কঙ্গো-কিনশাসা',
        'CF' => 'মধ্য আফ্রিকার প্রজাতন্ত্র',
        'CG' => 'কঙ্গো - ব্রাজাভিল',
        'CH' => 'সুইজারল্যান্ড',
        'CI' => 'কোত দিভোয়ার',
        'CK' => 'কুক দ্বীপপুঞ্জ',
        'CL' => 'চিলি',
        'CM' => 'ক্যামেরুন',
        'CN' => 'চীন',
        'CO' => 'কলম্বিয়া',
        'CR' => 'কোস্টারিকা',
        'CU' => 'কিউবা',
        'CV' => 'কেপভার্দে',
        'CW' => 'কুরাসাও',
        'CX' => 'ক্রিসমাস দ্বীপ',
        'CY' => 'সাইপ্রাস',
        'CZ' => 'চেচিয়া',
        'DE' => 'জার্মানি',
        'DJ' => 'জিবুতি',
        'DK' => 'ডেনমার্ক',
        'DM' => 'ডোমিনিকা',
        'DO' => 'ডোমেনিকান প্রজাতন্ত্র',
        'DZ' => 'আলজেরিয়া',
        'EC' => 'ইকুয়েডর',
        'EE' => 'এস্তোনিয়া',
        'EG' => 'মিশর',
        'EH' => 'পশ্চিম সাহারা',
        'ER' => 'ইরিত্রিয়া',
        'ES' => 'স্পেন',
        'ET' => 'ইথিওপিয়া',
        'FI' => 'ফিনল্যান্ড',
        'FJ' => 'ফিজি',
        'FK' => 'ফকল্যান্ড দ্বীপপুঞ্জ',
        'FM' => 'মাইক্রোনেশিয়া',
        'FO' => 'ফ্যারও দ্বীপপুঞ্জ',
        'FR' => 'ফ্রান্স',
        'GA' => 'গ্যাবন',
        'GB' => 'যুক্তরাজ্য',
        'GD' => 'গ্রেনাডা',
        'GE' => 'জর্জিয়া',
        'GF' => 'ফরাসী গায়ানা',
        'GG' => 'গুয়ার্নসি',
        'GH' => 'ঘানা',
        'GI' => 'জিব্রাল্টার',
        'GL' => 'গ্রীনল্যান্ড',
        'GM' => 'গাম্বিয়া',
        'GN' => 'গিনি',
        'GP' => 'গুয়াদেলৌপ',
        'GQ' => 'নিরক্ষীয় গিনি',
        'GR' => 'গ্রীস',
        'GS' => 'দক্ষিণ জর্জিয়া ও দক্ষিণ স্যান্ডউইচ দ্বীপপুঞ্জ',
        'GT' => 'গুয়াতেমালা',
        'GU' => 'গুয়াম',
        'GW' => 'গিনি-বিসাউ',
        'GY' => 'গিয়ানা',
        'HK' => 'হংকং এসএআর চীনা',
        'HM' => 'হার্ড এবং ম্যাকডোনাল্ড দ্বীপপুঞ্জ',
        'HN' => 'হন্ডুরাস',
        'HR' => 'ক্রোয়েশিয়া',
        'HT' => 'হাইতি',
        'HU' => 'হাঙ্গেরি',
        'ID' => 'ইন্দোনেশিয়া',
        'IE' => 'আয়ারল্যান্ড',
        'IL' => 'ইজরায়েল',
        'IM' => 'আইল অফ ম্যান',
        'IN' => 'ভারত',
        'IO' => 'ব্রিটিশ ভারত মহাসাগরীয় অঞ্চল',
        'IQ' => 'ইরাক',
        'IR' => 'ইরান',
        'IS' => 'আইসল্যান্ড',
        'IT' => 'ইতালি',
        'JE' => 'জার্সি',
        'JM' => 'জামাইকা',
        'JO' => 'জর্ডন',
        'JP' => 'জাপান',
        'KE' => 'কেনিয়া',
        'KG' => 'কিরগিজিস্তান',
        'KH' => 'কম্বোডিয়া',
        'KI' => 'কিরিবাতি',
        'KM' => 'কমোরোস',
        'KN' => 'সেন্ট কিটস ও নেভিস',
        'KP' => 'উত্তর কোরিয়া',
        'KR' => 'দক্ষিণ কোরিয়া',
        'KW' => 'কুয়েত',
        'KY' => 'কেম্যান দ্বীপপুঞ্জ',
        'KZ' => 'কাজাখস্তান',
        'LA' => 'লাওস',
        'LB' => 'লেবানন',
        'LC' => 'সেন্ট লুসিয়া',
        'LI' => 'লিচেনস্টেইন',
        'LK' => 'শ্রীলঙ্কা',
        'LR' => 'লাইবেরিয়া',
        'LS' => 'লেসোথো',
        'LT' => 'লিথুয়ানিয়া',
        'LU' => 'লাক্সেমবার্গ',
        'LV' => 'লাত্ভিয়া',
        'LY' => 'লিবিয়া',
        'MA' => 'মোরক্কো',
        'MC' => 'মোনাকো',
        'MD' => 'মলডোভা',
        'ME' => 'মন্টিনিগ্রো',
        'MF' => 'সেন্ট মার্টিন',
        'MG' => 'মাদাগাস্কার',
        'MH' => 'মার্শাল দ্বীপপুঞ্জ',
        'MK' => 'উত্তর ম্যাসেডোনিয়া',
        'ML' => 'মালি',
        'MM' => 'মায়ানমার (বার্মা)',
        'MN' => 'মঙ্গোলিয়া',
        'MO' => 'ম্যাকাও এসএআর চীনা চীনা (ম্যাকাও এসএআর চীনা) চীনা (ঐতিহ্যবাহী, ম্যাকাও এসএআর চীনা) অঞ্চল: ম্যাকাও এসএআর চীন',
        'MP' => 'উত্তরাঞ্চলীয় মারিয়ানা দ্বীপপুঞ্জ',
        'MQ' => 'মার্টিনিক',
        'MR' => 'মরিতানিয়া',
        'MS' => 'মন্টসেরাট',
        'MT' => 'মাল্টা',
        'MU' => 'মরিশাস',
        'MV' => 'মালদ্বীপ',
        'MW' => 'মালাউই',
        'MX' => 'মেক্সিকো',
        'MY' => 'মালয়েশিয়া',
        'MZ' => 'মোজাম্বিক',
        'NA' => 'নামিবিয়া',
        'NC' => 'নিউ ক্যালেডোনিয়া',
        'NE' => 'নাইজার',
        'NF' => 'নরফোক দ্বীপ',
        'NG' => 'নাইজেরিয়া',
        'NI' => 'নিকারাগুয়া',
        'NL' => 'নেদারল্যান্ডস',
        'NO' => 'নরওয়ে',
        'NP' => 'নেপাল',
        'NR' => 'নাউরু',
        'NU' => 'নিউয়ে',
        'NZ' => 'নিউজিল্যান্ড',
        'OM' => 'ওমান',
        'PA' => 'পানামা',
        'PE' => 'পেরু',
        'PF' => 'ফরাসী পলিনেশিয়া',
        'PG' => 'পাপুয়া নিউ গিনি',
        'PH' => 'ফিলিপাইন',
        'PK' => 'পাকিস্তান',
        'PL' => 'পোল্যান্ড',
        'PM' => 'সেন্ট পিয়ের ও মিকুয়েলন',
        'PN' => 'পিটকেয়ার্ন দ্বীপপুঞ্জ',
        'PR' => 'পুয়ের্তো রিকো',
        'PS' => 'প্যালেস্টাইনের অঞ্চলসমূহ',
        'PT' => 'পর্তুগাল',
        'PW' => 'পালাউ',
        'PY' => 'প্যারাগুয়ে',
        'QA' => 'কাতার',
        'RE' => 'রিইউনিয়ন',
        'RO' => 'রোমানিয়া',
        'RS' => 'সার্বিয়া',
        'RU' => 'রাশিয়া',
        'RW' => 'রুয়ান্ডা',
        'SA' => 'সৌদি আরব',
        'SB' => 'সলোমন দ্বীপপুঞ্জ',
        'SC' => 'সিসিলি',
        'SD' => 'সুদান',
        'SE' => 'সুইডেন',
        'SG' => 'সিঙ্গাপুর',
        'SH' => 'সেন্ট হেলেনা',
        'SI' => 'স্লোভানিয়া',
        'SJ' => 'স্বালবার্ড ও জান মেয়েন',
        'SK' => 'স্লোভাকিয়া',
        'SL' => 'সিয়েরা লিওন',
        'SM' => 'সান মারিনো',
        'SN' => 'সেনেগাল',
        'SO' => 'সোমালিয়া',
        'SR' => 'সুরিনাম',
        'SS' => 'দক্ষিণ সুদান',
        'ST' => 'সাওটোমা ও প্রিন্সিপি',
        'SV' => 'এল সালভেদর',
        'SX' => 'সিন্ট মার্টেন',
        'SY' => 'সিরিয়া',
        'SZ' => 'ইসওয়াতিনি',
        'TC' => 'তুর্কস ও কাইকোস দ্বীপপুঞ্জ',
        'TD' => 'চাদ',
        'TF' => 'ফরাসী দক্ষিণাঞ্চল',
        'TG' => 'টোগো',
        'TH' => 'থাইল্যান্ড',
        'TJ' => 'তাজিকিস্তান',
        'TK' => 'টোকেলাউ',
        'TL' => 'তিমুর-লেস্তে',
        'TM' => 'তুর্কমেনিস্তান',
        'TN' => 'তিউনিসিয়া',
        'TO' => 'টোঙ্গা',
        'TR' => 'তুরস্ক',
        'TT' => 'ত্রিনিনাদ ও টোব্যাগো',
        'TV' => 'টুভালু',
        'TW' => 'তাইওয়ান',
        'TZ' => 'তাঞ্জানিয়া',
        'UA' => 'ইউক্রেন',
        'UG' => 'উগান্ডা',
        'UM' => 'যুক্তরাষ্ট্রের পার্শ্ববর্তী দ্বীপপুঞ্জ',
        'US' => 'মার্কিন যুক্তরাষ্ট্র',
        'UY' => 'উরুগুয়ে',
        'UZ' => 'উজবেকিস্তান',
        'VA' => 'ভ্যাটিকান সিটি',
        'VC' => 'সেন্ট ভিনসেন্ট ও গ্রেনাডিনস',
        'VE' => 'ভেনেজুয়েলা',
        'VG' => 'ব্রিটিশ ভার্জিন দ্বীপপুঞ্জ',
        'VI' => 'মার্কিন যুক্তরাষ্ট্রের ভার্জিন দ্বীপপুঞ্জ',
        'VN' => 'ভিয়েতনাম',
        'VU' => 'ভানুয়াটু',
        'WF' => 'ওয়ালিস ও ফুটুনা',
        'WS' => 'সামোয়া',
        'YE' => 'ইয়েমেন',
        'YT' => 'মায়োত্তে',
        'ZA' => 'দক্ষিণ আফ্রিকা',
        'ZM' => 'জাম্বিয়া',
        'ZW' => 'জিম্বাবোয়ে',
    ],
];

==> symfony_8.0.5+dfsg.orig.tar.xz: symfony-8.0.5/src/Symfony/Component/Intl/Resources/data/regions/bn.php <==
<?php

return [
    'UserAssignedNames' => [
        'XK' => 'কসোভো',
    ],
    'Names' => [
        'AD' => 'আন্ডোরা',
        'AE' => 'সংযুক্ত আরব আমিরাত',
        'AF' => 'আফগানিস্তান',
        'AG' => 'অ্যান্টিগুয়া ও বারবুডা',
        'AI' => 'অ্যাঙ্গুইলা',
        'AL' => 'আলবেনিয়া',
        'AM' => 'আর্মেনিয়া',
        'AO' => 'অ্যাঙ্গোলা',
        'AQ' => 'অ্যান্টার্কটিকা',
        'AR' => 'আর্জেন্টিনা',
        'AS' => 'আমেরিকান সামোয়া',
        'AT' => 'অস্ট্রিয়া',
        'AU' => 'অস্ট্রেলিয়া',
        'AW' => 'আরুবা',
        'AX' => 'অলান্ড দ্বীপপুঞ্জ',
        'AZ' => 'আজারবাইজান',
        'BA' => 'বসনিয়া ও হার্জেগোভিনা',
        'BB' => 'বার্বাডোজ',
        'BD' => 'বাংলাদেশ',
        'BE' => 'বেলজিয়াম',
        'BF' => 'বুরকিনা ফাসো',
        'BG' => 'বুলগেরিয়া',
        'BH' => 'বাহারিন',
        'BI' => 'বুরুন্ডি',
        'BJ' => 'বেনিন',
        'BL' => 'সেন্ট বার্থেলেমি',
        'BM' => 'বারমুডা',
        'BN' => 'ব্রুনেই',
        'BO' => 'বলিভিয়া',
        'BQ' => 'ক্যারিবিয়ান নেদারল্যান্ডস',
        'BR' => 'ব্রাজিল',
        'BS' => 'বাহামা দ্বীপপুঞ্জ',
        'BT' => 'ভুটান',
        'BV' => 'বোভেট দ্বীপ',
        'BW' => 'বতসোয়ানা',
        'BY' => 'বেলারুশ',
        'BZ' => 'বেলিজ',
        'CA' => 'কানাডা',
        'CC' => 'কোকোস (কিলিং) দ্বীপপুঞ্জ',
        'CD' => 'কঙ্গো-কিনশাসা',
        'CF' => 'মধ্য আফ্রিকান প্রজাতন্ত্র',
        'CG' => 'কঙ্গো - ব্রাজাভিল',
        'CH' => 'সুইজারল্যান্ড',
        'CI' => 'কোট ডি‘আইভোর',
        'CK' => 'কুক দ্বীপপুঞ্জ',
        'CL' => 'চিলি',
        'CM' => 'ক্যামেরুন',
        'CN' => 'চীন',
        'CO' => 'কলম্বিয়া',
        'CR' => 'কোস্টারিকা',
        'CU' => 'কিউবা',
        'CV' => 'কেপ ভার্দে',
        'CW' => 'কুরাসাও',
        'CX' => 'ক্রিসমাস দ্বীপ',
        'CY' => 'সাইপ্রাস',
        'CZ' => 'চেকিয়া',
        'DE' => 'জার্মানি',
        'DJ' => 'জিবুতি',
        'DK' => 'ডেনমার্ক',
        'DM' => 'ডোমিনিকা',
        'DO' => 'ডোমেনিকান প্রজাতন্ত্র',
        'DZ' => 'আলজেরিয়া',
        'EC' => 'ইকুয়েডর',
        'EE' => 'এস্তোনিয়া',
        'EG' => 'মিশর',
        'EH' => 'পশ্চিম সাহারা',
        'ER' => 'ইরিত্রিয়া',
        'ES' => 'স্পেন',
        'ET' => 'ইথিওপিয়া',
        'FI' => 'ফিনল্যান্ড',
        'FJ' => 'ফিজি',
        'FK' => 'ফকল্যান্ড দ্বীপপুঞ্জ',
        'FM' => 'মাইক্রোনেশিয়া',
        'FO' => 'ফ্যারো দ্বীপপুঞ্জ',
        'FR' => 'ফ্রান্স',
        'GA' => 'গ্যাবন',
        'GB' => 'যুক্তরাজ্য',
        'GD' => 'গ্রেনাডা',
        'GE' => 'জর্জিয়া',
        'GF' => 'ফরাসী গায়ানা',
        'GG' => 'গার্নসি',
        'GH' => 'ঘানা',
        'GI' => 'জিব্রাল্টার',
        'GL' => 'গ্রীনল্যান্ড',
        'GM' => 'গাম্বিয়া',
        'GN' => 'গিনি',
        'GP' => 'গুয়াদেলৌপ',
        'GQ' => 'নিরক্ষীয় গিনি',
        'GR' => 'গ্রীস',
        'GS' => 'দক্ষিণ জর্জিয়া ও দক্ষিণ স্যান্ডউইচ দ্বীপপুঞ্জ',
        'GT' => 'গুয়াতেমালা',
        'GU' => 'গুয়াম',
        'GW' => 'গিনি-বিসাউ',
        'GY' => 'গিয়ানা',
        'HK' => 'হংকং এসএআর চীনা',
        'HM' => 'হার্ড এবং ম্যাকডোনাল্ড দ্বীপপুঞ্জ',
        'HN' => 'হন্ডুরাস',
        'HR' => 'ক্রোয়েশিয়া',
        'HT' => 'হাইতি',
        'HU' => 'হাঙ্গেরি',
        'ID' => 'ইন্দোনেশিয়া',
        'IE' => 'আয়ারল্যান্ড',
        'IL' => 'ইজরায়েল',
        'IM' => 'আইল অফ ম্যান',
        'IN' => 'ভারত',
        'IO' => 'ব্রিটিশ ভারত মহাসাগরীয় অঞ্চল',
        'IQ' => 'ইরাক',
        'IR' => 'ইরান',
        'IS' => 'আইসল্যান্ড',
        'IT' => 'ইতালি',
        'JE' => 'জার্সি',
        'JM' => 'জামাইকা',
        'JO' => 'জর্ডন',
        'JP' => 'জাপান',
        'KE' => 'কেনিয়া',
        'KG' => 'কিরগিজিস্তান',
        'KH' => 'কম্বোডিয়া',
        'KI' => 'কিরিবাতি',
        'KM' => 'কমোরোস',
        'KN' => 'সেন্ট কিটস ও নেভিস',
        'KP' => 'উত্তর কোরিয়া',
        'KR' => 'দক্ষিণ কোরিয়া',
        'KW' => 'কুয়েত',
        'KY' => 'কেম্যান দ্বীপপুঞ্জ',
        'KZ' => 'কাজাখস্তান',
        'LA' => 'লাওস',
        'LB' => 'লেবানন',
        'LC' => 'সেন্ট লুসিয়া',
        'LI' => 'লিচেনস্টেইন',
        'LK' => 'শ্রীলঙ্কা',
        'LR' => 'লাইবেরিয়া',
        'LS' => 'লেসোথো',
        'LT' => 'লিথুয়ানিয়া',
        'LU' => 'লাক্সেমবার্গ',
        'LV' => 'লাটভিয়া',
        'LY' => 'লিবিয়া',
        'MA' => 'মরক্কো',
        'MC' => 'মোনাকো',
        'MD' => 'মলডোভা',
        'ME' => 'মন্টিনিগ্রো',
        'MF' => 'সেন্ট মার্টিন',
        'MG' => 'মাদাগাস্কার',
        'MH' => 'মার্শাল দ্বীপপুঞ্জ',
        'MK' => 'উত্তর ম্যাসেডোনিয়া',
        'ML' => 'মালি',
        'MM' => 'মায়ানমার (বার্মা)',
        'MN' => 'মঙ্গোলিয়া',
        'MO' => 'ম্যাকাও এসএআর চীন',
        'MP' => 'উত্তরাঞ্চলীয় মারিয়ানা দ্বীপপুঞ্জ',
        'MQ' => 'মার্টিনিক',
        'MR' => 'মরিতানিয়া',
        'MS' => 'মন্টসেরাট',
        'MT' => 'মাল্টা',
        'MU' => 'মরিশাস',
        'MV' => 'মালদ্বীপ',
        'MW' => 'মালাউই',
        'MX' => 'মেক্সিকো',
        'MY' => 'মালয়েশিয়া',
        'MZ' => 'মোজাম্বিক',
        'NA' => 'নামিবিয়া',
        'NC' => 'নিউ ক্যালেডোনিয়া',
        'NE' => 'নাইজার',
        'NF' => 'নরফোক দ্বীপ',
        'NG' => 'নাইজেরিয়া',
        'NI' => 'নিকারাগুয়া',
        'NL' => 'নেদারল্যান্ডস',
        'NO' => 'নরওয়ে',
        'NP' => 'নেপাল',
        'NR' => 'নাউরু',
        'NU' => 'নিউয়ে',
        'NZ' => 'নিউজিল্যান্ড',
        'OM' => 'ওমান',
        'PA' => 'পানামা',
        'PE' => 'পেরু',
        'PF' => 'ফরাসী পলিনেশিয়া',
        'PG' => 'পাপুয়া নিউ গিনি',
        'PH' => 'ফিলিপাইন',
        'PK' => 'পাকিস্তান',
        'PL' => 'পোল্যান্ড',
        'PM' => 'সেন্ট পিয়ের ও মিকুয়েলন',
        'PN' => 'পিটকেয়ার্ন দ্বীপপুঞ্জ',
        'PR' => 'পুয়ের্তো রিকো',
        'PS' => 'প্যালেস্টাইন ভূখণ্ড',
        'PT' => 'পর্তুগাল',
        'PW' => 'পালাউ',
        'PY' => 'প্যারাগুয়ে',
        'QA' => 'কাতার',
        'RE' => 'রিইউনিয়ন',
        'RO' => 'রোমানিয়া',
        'RS' => 'সার্বিয়া',
        'RU' => 'রাশিয়া',
        'RW' => 'রুয়ান্ডা',
        'SA' => 'সৌদি আরব',
        'SB' => 'সলোমন দ্বীপপুঞ্জ',
        'SC' => 'সিসিলি',
        'SD' => 'সুদান',
        'SE' => 'সুইডেন',
        'SG' => 'সিঙ্গাপুর',
        'SH' => 'সেন্ট হেলেনা',
        'SI' => 'স্লোভানিয়া',
        'SJ' => 'স্বালবার্ড ও জান মেয়েন',
        'SK' => 'স্লোভাকিয়া',
        'SL' => 'সিয়েরা লিওন',
        'SM' => 'সান মারিনো',
        'SN' => 'সেনেগাল',
        'SO' => 'সোমালিয়া',
        'SR' => 'সুরিনাম',
        'SS' => 'দক্ষিণ সুদান',
        'ST' => 'সাওটোমা ও প্রিন্সিপি',
        'SV' => 'এল সালভেদর',
        'SX' => 'সিন্ট মার্টেন',
        'SY' => 'সিরিয়া',
        'SZ' => 'ইসওয়াতিনি',
        'TC' => 'তুর্কস ও কাইকোস দ্বীপপুঞ্জ',
        'TD' => 'চাদ',
        'TF' => 'ফরাসী দক্ষিণাঞ্চল',
        'TG' => 'টোগো',
        'TH' => 'থাইল্যান্ড',
        'TJ' => 'তাজিকিস্তান',
        'TK' => 'টোকেলাউ',
        'TL' => 'তিমুর-লেস্তে',
        'TM' => 'তুর্কমেনিস্তান',
        'TN' => 'তিউনিসিয়া',
        'TO' => 'টোঙ্গা',
        'TR' => 'তুরস্ক',
        'TT' => 'ত্রিনিদাদ ও টোবাগো',
        'TV' => 'টুভালু',
        'TW' => 'তাইওয়ান',
        'TZ' => 'তাঞ্জানিয়া',
        'UA' => 'ইউক্রেন',
        'UG' => 'উগান্ডা',
        'UM' => 'যুক্তরাষ্ট্রের পার্শ্ববর্তী দ্বীপপুঞ্জ',
        'US' => 'মার্কিন যুক্তরাষ্ট্র',
        'UY' => 'উরুগুয়ে',
        'UZ' => 'উজবেকিস্তান',
        'VA' => 'ভ্যাটিকান সিটি',
        'VC' => 'সেন্ট ভিনসেন্ট ও গ্রেনাডিনস',
        'VE' => 'ভেনেজুয়েলা',
        'VG' => 'ব্রিটিশ ভার্জিন দ্বীপপুঞ্জ',
        'VI' => 'মার্কিন যুক্তরাষ্ট্রীয় ভার্জিন দ্বীপপুঞ্জ',
        'VN' => 'ভিয়েতনাম',
        'VU' => 'ভানুয়াটু',
        'WF' => 'ওয়ালিস ও ফুটুনা',
        'WS' => 'সামোয়া',
        'YE' => 'ইয়েমেন',
        'YT' => 'মায়োত্তে',
        'ZA' => 'দক্ষিণ আফ্রিকা',
        'ZM' => 'জাম্বিয়া',
        'ZW' => 'জিম্বাবোয়ে',
    ],
];
